@@ -17,28 +17,26 @@ PID::File::Guard - Provides scope guard to remove the pid file automatically.
 
 =head3 new
 
- my $guard = PID::File::Guard->new( $object, 'method' );
+ my $guard = PID::File::Guard->new( sub { $pid_file->remove } );
 
-Creates a new guard token that will call the C<method> on the C<object> when it goes out of scope. 
+Creates a new guard token that will call the supplied sub when it goes out of scope. 
 
 =cut
 
 sub new
 {
-	my ( $class, $object, $method ) = @_;
+	my ( $class, $sub ) = @_;
 	die "Can't create guard in void context" if ! defined wantarray;
-	return bless { object => $object, method => $method }, $class;
+	return bless $sub, $class;
 }
 
 sub DESTROY
 {
 	my $self = shift;
-	
-	my $object = $self->{ object } or return;
-	my $method = $self->{ method };
-	
-	$object->$method; 
+
+	$self->();
 }
 
+
 1;
 
